src/hotspot/share/memory/allocation.hpp
changeset 51264 cf34c71ca27c
parent 49590 66c32f2a7f10
child 51617 9720ad0a40b6
--- a/src/hotspot/share/memory/allocation.hpp	Mon Jul 30 16:35:54 2018 -0400
+++ b/src/hotspot/share/memory/allocation.hpp	Tue Jul 31 07:35:16 2018 -0400
@@ -113,29 +113,30 @@
  */
 enum MemoryType {
   // Memory type by sub systems. It occupies lower byte.
-  mtJavaHeap          = 0x00,  // Java heap
-  mtClass             = 0x01,  // memory class for Java classes
-  mtThread            = 0x02,  // memory for thread objects
-  mtThreadStack       = 0x03,
-  mtCode              = 0x04,  // memory for generated code
-  mtGC                = 0x05,  // memory for GC
-  mtCompiler          = 0x06,  // memory for compiler
-  mtInternal          = 0x07,  // memory used by VM, but does not belong to
-                                 // any of above categories, and not used for
-                                 // native memory tracking
-  mtOther             = 0x08,  // memory not used by VM
-  mtSymbol            = 0x09,  // symbol
-  mtNMT               = 0x0A,  // memory used by native memory tracking
-  mtClassShared       = 0x0B,  // class data sharing
-  mtChunk             = 0x0C,  // chunk that holds content of arenas
-  mtTest              = 0x0D,  // Test type for verifying NMT
-  mtTracing           = 0x0E,  // memory used for Tracing
-  mtLogging           = 0x0F,  // memory for logging
-  mtArguments         = 0x10,  // memory for argument processing
-  mtModule            = 0x11,  // memory for module processing
-  mtNone              = 0x12,  // undefined
-  mt_number_of_types  = 0x13   // number of memory types (mtDontTrack
-                                 // is not included as validate type)
+  mtJavaHeap,          // Java heap
+  mtClass,             // memory class for Java classes
+  mtThread,            // memory for thread objects
+  mtThreadStack,
+  mtCode,              // memory for generated code
+  mtGC,                // memory for GC
+  mtCompiler,          // memory for compiler
+  mtInternal,          // memory used by VM, but does not belong to
+                       // any of above categories, and not used for
+                       // native memory tracking
+  mtOther,             // memory not used by VM
+  mtSymbol,            // symbol
+  mtNMT,               // memory used by native memory tracking
+  mtClassShared,       // class data sharing
+  mtChunk,             // chunk that holds content of arenas
+  mtTest,              // Test type for verifying NMT
+  mtTracing,           // memory used for Tracing
+  mtLogging,           // memory for logging
+  mtArguments,         // memory for argument processing
+  mtModule,            // memory for module processing
+  mtSafepoint,         // memory for safepoint support
+  mtNone,              // undefined
+  mt_number_of_types   // number of memory types (mtDontTrack
+                       // is not included as validate type)
 };
 
 typedef MemoryType MEMFLAGS;